@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterlistmodel.h"
 #include "filter.h"
@@ -53,7 +38,7 @@ void FilterListModel::removeFilter(Filter *f)
 Filter *FilterListModel::filterForIndex(const QModelIndex &idx)
 {
     if (!idx.isValid())
-        return 0;
+        return nullptr;
 
     return filters.at(idx.row());
 }
@@ -64,7 +49,7 @@ Filter *FilterListModel::filterByName(const QString &name)
         if (f->filterName() == name)
             return f;
 
-    return 0;
+    return nullptr;
 }
 
 Filter *FilterListModel::filterByID(const QString &id)
@@ -73,13 +58,13 @@ Filter *FilterListModel::filterByID(const QString &id)
         if (f->filterID() == id)
             return f;
 
-    return 0;
+    return nullptr;
 }
 
 Filter *FilterListModel::filterByRow(int row)
 {
     if (row < 0 || row >= filters.count())
-        return 0;
+        return nullptr;
     else
         return filters.at(row);
 }
